==> haskell-persistent-test-2.13.1.3-173-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-7tmGXTqJbs38MjGoGET1LG
key:                  persistent-test-2.13.1.3-7tmGXTqJbs38MjGoGET1LG
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  a7ebfe295826d74ae06deea47016a46d
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-7tmGXTqJbs38MjGoGET1LG
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.15.0.1-Fs5gw6qOmgJQY49llBRf6
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    blaze-html-0.9.2.0-BsVDj7UmD9SGJonPOQFUuj bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1 containers-0.6.7
    exceptions-0.10.5 hspec-2.11.0.1-3rAJnF5rW5rEegfMOAzyJL
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    http-api-data-0.6.1-FahDGTMw50P4NKEAb3IwkU
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl
    monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    quickcheck-instances-0.3.32-5Z6Bwsow2SRH004ovX5X92
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.13.1.3-194-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-5SpCvIXH8jyGvEQDWbU2fF
key:                  persistent-test-2.13.1.3-5SpCvIXH8jyGvEQDWbU2fF
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  ac1431239deaf5435c9fd5d787fadbb3
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-5SpCvIXH8jyGvEQDWbU2fF
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    blaze-html-0.9.2.0-3cSCYM9QSR99BQnVHXrYzE bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3 containers-0.6.7
    exceptions-0.10.5 hspec-2.11.4-HeteQh8xgtfLgehpo4VbZM
    hspec-expectations-0.8.4-8kbQPZh0Wgi2TqXq1qz92F
    http-api-data-0.6.1-Ct3YGnpgXQS6uC3vp2y6CM
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    quickcheck-instances-0.3.33-KfcC5wamxYWHrsGNB6FgIV
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
